##########################################################################
# DIRECTIONS:
#
# In the section below, you'll find several helper functions that have 
# been partially implemented for a game of Tic-Tac-Toe. The provided 
# functions include show(board), check_winner(board), get_player_move(), 
# and play_tic_tac_toe(). You should skim through their code to
# understand how they fit together, but you should be able to implement the
# two missing functions, make_board(n, fill_value) and move(board, coordinates, value), 
# just by reading the descriptions in their docstrings.
#
# Your task is to implement the missing functions make_board and move. 
# Once you've implemented them, you can test your code by calling the 
#play_tic_tac_toe() function.
##########################################################################

#####################       PROVIDED HELPERS      ########################
def show(board):
    """
    Print the game board.

    Args:
        board (list): A list of lists representing the game board.

    Returns:
        None
    """
    for row in board:
        print(row,"\n")

def check_winner(board):
    """
    Check if there is a winner on the board.

    Args:
        board (list): A list of lists representing the game board.

    Returns:
        str or None: The symbol of the winner ("X" or "O") if there is a winner, or None if there is no winner.
    """
    # Check rows and columns for a winner
    for i in range(3):
        if board[i][0] == board[i][1] == board[i][2] != "*":
            return board[i][0]  # Winner in row i
        if board[0][i] == board[1][i] == board[2][i] != "*":
            return board[0][i]  # Winner in column i
    
    # Check diagonals for a winner
    if board[0][0] == board[1][1] == board[2][2] != "*":
        return board[0][0]  # Winner in diagonal from top-left to bottom-right
    if board[0][2] == board[1][1] == board[2][0] != "*":
        return board[0][2]  # Winner in diagonal from top-right to bottom-left
    
    return None  # No winner found

def get_player_move():
    """
    Prompt the player to enter their move.

    Returns:
        tuple: A tuple of integers (i, j) representing the row and column indices.
    """
    while True:
        try:
            i = int(input("Enter row number (0, 1, or 2): "))
            j = int(input("Enter column number (0, 1, or 2): "))
            return (i, j)
        except ValueError:
            print("Invalid input. Please enter a number.")

def play_tic_tac_toe():
    tic_tac_toe_board = make_board(3, "*")
    print("Initial board:")
    show(tic_tac_toe_board)

    for turn in range(9):
        if turn % 2 == 0:
            player = "X"
        else:
            player = "O"

        print(f"\nPlayer {player}'s turn:")
        move_made = False

        while not move_made:
            row, col = get_player_move()
            if tic_tac_toe_board[row][col] == "*":
                move(tic_tac_toe_board, (row, col), player)
                move_made = True
            else:
                print("That spot is already taken. Try again.")

        print("\nBoard after making move:")
        show(tic_tac_toe_board)

        # Check for a winner after each move (optional)
        # If there's a winner, end the game
        # Check for a winner
        winner = check_winner(tic_tac_toe_board)
        if winner:
            print(f"\nPlayer {winner} wins!")
            break
    else:
        print("\nIt's a draw!")
######################       END OF PROVIDED HELPERS     ##################


def make_board(n, fill_value):
    """
    Create a square game board of size n x n, filled with the specified value.

    Args:
        n (int): The number of rows and columns in the board.
        fill_value (str): The value to fill the board with.

    Returns:
        list: An n x n list of lists representing the game board.

    Example usage:
        print(make_board(4,":)"))
        # prints [[':)', ':)', ':)', ':)'], [':)', ':)', ':)', ':)'], [':)', ':)', ':)', ':)'], [':)', ':)', ':)', ':)']]
        print(make_board(1,"."))
        #prints [["."]]
    """
    row = []
    for i in range(n):
        row.append(fill_value)
    # FINISH THE FUNCTION HERE


def move(board, coordinates, value):
    """
    Update the board at the specified coordinates with the given value.

    Args:
        board (list): A list of lists representing the game board.
        coordinates (tuple): A tuple of integers (i, j) representing the row and column indices.
        value (str): The value to place at the specified coordinates ("X" or "O").

    Returns:
        None

    Example Usage:
    dots = make_board(3, "a")
    move(dots, (1,2), 'b')
    show(dots)
    # this should print
    # ['a', 'a', 'a'] 

    # ['a', 'a', 'b']

    # ['a', 'a', 'a']

    """
    # YOUR CODE HERE!


# You can uncomment this line to test your code.
# play_tic_tac_toe()